OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU 資訊暫時無法使用",
    "Load average: {cpu} (last minute)" : "平均負載：{cpu}（前ㄧ分鐘）",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM：總計 {memTotalBytes}／目前使用量：{memUsageBytes}",
    "RAM info not available" : "沒有可用的 RAM 資訊",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP：總計 {swapTotalBytes}／目前使用量：{swapUsageBytes}",
    "SWAP info not available" : "沒有可用的 SWAP 資訊",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "請按⌘-C以複製。",
    "Press Ctrl-C to copy." : "請按Ctrl-C以複製。",
    "System" : "系統",
    "Monitoring" : "監控",
    "Monitoring app with useful server information" : "使用有用的伺服器訊息以監控應用程式",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "提供有用的伺服器訊息，例如CPU負載、記憶體使用情況、磁碟使用情況、用戶數等。",
    "Operating System:" : "作業系統：",
    "CPU:" : "CPU：",
    "Unknown Processor" : "未知的處理器",
    "Memory:" : "記憶體：",
    "Server time:" : "伺服器時間：",
    "Uptime:" : "運作時間：",
    "Temperature" : "氣溫",
    "Load" : "負載",
    "Memory" : "記憶體",
    "Disk" : "硬碟",
    "Mount:" : "掛載：",
    "Filesystem:" : "檔案系統：",
    "Size:" : "大小:",
    "Available:" : "可用：",
    "Used:" : "已使用：",
    "Files:" : "檔案:",
    "Storages:" : "儲存設備：",
    "Free Space:" : "可用空間：",
    "Network" : "網路",
    "Hostname:" : "主機名稱：",
    "DNS:" : "DNS：",
    "Gateway:" : "網路閘道：",
    "Status:" : "狀態：",
    "Speed:" : "速度：",
    "Duplex:" : "雙工：",
    "MAC:" : "MAC：",
    "IPv4:" : "IPv4：",
    "IPv6:" : "IPv6：",
    "Active users" : "活動中的使用者",
    "Total users:" : "總使用者：",
    "24 hours:" : "24小時：",
    "1 hour:" : "1小時：",
    "5 mins:" : "5分鐘：",
    "Shares" : "分享",
    "Users:" : "使用者:",
    "Groups:" : "群組：",
    "Links:" : "連結：",
    "Emails:" : "電子郵件：",
    "Federated sent:" : "聯盟傳送：",
    "Federated received:" : "聯盟接收：",
    "Talk conversations:" : "Talk 對話：",
    "PHP" : "PHP",
    "Version:" : "版本:",
    "Memory limit:" : "記憶體限制：",
    "Max execution time:" : "最大執行時間：",
    "Upload max size:" : "上傳至多:",
    "OPcache Revalidate Frequency:" : "OPcache 重新驗證頻率：",
    "Extensions:" : "擴充套件：",
    "Unable to list extensions" : "無法列出擴充套件",
    "Show phpinfo" : "顯示 phpinfo",
    "Database" : "資料庫",
    "Type:" : "類型:",
    "External monitoring tool" : "外部監控工具",
    "Use this end point to connect an external monitoring tool:" : "使用此端點連結外部監控工具：",
    "Copy" : "複製",
    "Output in JSON" : "以 JSON 輸出",
    "Skip app updates (including app updates will send an external request to the app store)" : "略過應用程式更新（包含應用程式更新將會向應用程式商店傳送外部請求）",
    "Skip server update" : "略過伺服器更新",
    "To use an access token, please generate one then set it using the following command:" : "要使用存取權杖，請產生一個，然後使用下列指令設定：",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "然後在查詢上面的 URL 時，將權杖與「NC-Token」標頭一起傳遞。"
},
"nplurals=1; plural=0;");
